Skip to content
Commits on Source (3)
pywps (4.2.1-2) UNRELEASED; urgency=medium
pywps (4.2.1-2~exp1) experimental; urgency=medium
* Bump Standards-Version to 4.3.0, no changes.
* Remove package name from lintian overrides.
* Switch to Python 3.
* Add patch for Python 3.7 compatibility.
-- Bas Couwenberg <sebastic@debian.org> Tue, 25 Dec 2018 23:10:43 +0100
-- Bas Couwenberg <sebastic@debian.org> Sat, 30 Mar 2019 20:59:32 +0100
pywps (4.2.1-1) unstable; urgency=medium
......
......@@ -9,60 +9,57 @@ Build-Depends: debhelper (>= 9),
dh-python,
libjs-mathjax,
lsb-release,
python-all,
python-dateutil,
python-flufl.enum,
python-gdal,
python-jinja2,
python-jsonschema,
python-lxml,
python-netcdf4,
python-owslib,
python-pathlib,
python-requests,
python-setuptools,
python-sphinx,
python3-all,
python3-dateutil,
python3-flufl.enum,
python3-gdal,
python3-jinja2,
python3-jsonschema,
python3-lxml,
python3-netcdf4,
python3-owslib,
python3-requests,
python3-setuptools,
python3-sphinx,
python-sqlalchemy,
python-werkzeug
python3-sqlalchemy,
python3-werkzeug
Standards-Version: 4.3.0
Vcs-Browser: https://salsa.debian.org/debian-gis-team/pywps
Vcs-Git: https://salsa.debian.org/debian-gis-team/pywps.git
Homepage: http://pywps.org
Package: python-pywps
Package: python3-pywps
Architecture: all
Depends: python-dateutil,
python-flufl.enum,
python-gdal,
python-jinja2,
python-jsonschema,
python-lxml,
python-owslib,
python-pathlib,
python-requests,
python-sqlalchemy,
python-werkzeug,
${python:Depends},
Depends: python3-dateutil,
python3-flufl.enum,
python3-gdal,
python3-jinja2,
python3-jsonschema,
python3-lxml,
python3-owslib,
python3-requests,
python3-sqlalchemy,
python3-werkzeug,
${python3:Depends},
${misc:Depends}
Recommends: python-mapscript,
python-netcdf4,
python-pyproj
Recommends: python3-mapscript,
python3-netcdf4,
python3-pyproj
Suggests: grass-core,
r-base
Description: Implementation of OGC's Web Processing Service - Python 2 module
Description: Implementation of OGC's Web Processing Service - Python module
PyWPS is implementation of Web Processing Service from Open
Geospatial Consortium Inc.(R) with help of Python Programming
Language and GIS GRASS as working tool in background.
.
This package contains the pywps module for Python 2.
This package contains the pywps Python module.
Package: pywps
Architecture: all
Section: metapackages
Depends: python-pywps (>= ${source:Version}),
Depends: python3-pywps (>= ${source:Version}),
pywps-wsgi (>= ${source:Version}),
${python:Depends},
${python3:Depends},
${misc:Depends}
Suggests: cgi-mapserver,
pywps-doc
......
Description: Rename async to async_ for Python 3.7 compatibility.
async became a reserved keyword in Python 3.7:
.
> Backwards incompatible syntax changes:
>
> * [async](https://docs.python.org/3/reference/compound_stmts.html#async) and [await](https://docs.python.org/3/reference/expressions.html#await) are now reserved keywords.
.
https://docs.python.org/3/whatsnew/3.7.html
Author: Bas Couwenberg <sebastic@debian.org>
Forwarded: https://github.com/geopython/pywps/pull/462
--- a/docs/Makefile
+++ b/docs/Makefile
@@ -3,7 +3,7 @@
# You can set these variables from the command line.
SPHINXOPTS =
-SPHINXBUILD = sphinx-build -W
+SPHINXBUILD = /usr/share/sphinx/scripts/python2/sphinx-build -W
PAPER =
BUILDDIR = _build
offline-tests.patch
use-mathjax-package.patch
privacy-breach.patch
python2-sphinx.patch
python-3.7.patch
......@@ -23,7 +23,7 @@ ifeq ($(VENDOR_DERIVES_FROM_UBUNTU),yes)
endif
%:
dh $@ --with apache2,python2,sphinxdoc --buildsystem=pybuild --parallel
dh $@ --with apache2,python3,sphinxdoc --buildsystem=pybuild --parallel
override_auto_clean:
dh_auto_clean
......
# Package will switch to Python 3 when Python 2 is EOL.
python-foo-but-no-python3-foo python-pywps
# Not worth the effort
testsuite-autopkgtest-missing
--- a/pywps/app/Process.py
+++ b/pywps/app/Process.py
@@ -96,7 +96,7 @@ class Process(object):
def execute(self, wps_request, uuid):
self._set_uuid(uuid)
- self.async = False
+ self.async_ = False
response_cls = get_response("execute")
wps_response = response_cls(wps_request, process=self, uuid=self.uuid)
@@ -110,13 +110,13 @@ class Process(object):
raise OperationNotSupported('Process does not support the updating of status')
wps_response.store_status_file = True
- self.async = True
+ self.async_ = True
else:
wps_response.store_status_file = False
LOGGER.debug('Check if updating of status is not required then no need to spawn a process')
- wps_response = self._execute_process(self.async, wps_request, wps_response)
+ wps_response = self._execute_process(self.async_, wps_request, wps_response)
return wps_response
@@ -138,11 +138,11 @@ class Process(object):
self.status_location = os.path.join(file_path, str(self.uuid)) + '.xml'
self.status_url = os.path.join(file_url, str(self.uuid)) + '.xml'
- def _execute_process(self, async, wps_request, wps_response):
+ def _execute_process(self, async_, wps_request, wps_response):
"""Uses :module:`pywps.processing` module for sending process to
background BUT first, check for maxprocesses configuration value
:param async: run in asynchronous mode
:return: wps_response or None
"""
@@ -151,7 +151,7 @@ class Process(object):
stored = dblog.get_stored().count()
# async
- if async:
+ if async_:
# run immedietly
if running < maxparallel or maxparallel == -1:
@@ -257,7 +257,7 @@ class Process(object):
process_identifier = new_wps_request.identifier
process = self.service.prepare_process_for_execution(process_identifier)
process._set_uuid(uuid)
- process.async = True
+ process.async_ = True
new_wps_response = ExecuteResponse(new_wps_request, process=process, uuid=uuid)
process._run_async(new_wps_request, new_wps_response)
dblog.remove_stored(uuid)
@@ -138,11 +138,11 @@ class Process(object):
"""Uses :module:`pywps.processing` module for sending process to
background BUT first, check for maxprocesses configuration value
- :param async: run in asynchronous mode
+ :param async_: run in asynchronous mode
:return: wps_response or None
"""
Description: Use Python 2 version of Sphinx explicitly.
Author: Bas Couwenberg <sebastic@debian.org>
Forwarded: not-needed